actions_slash_get_org_secret

Function actions_slash_get_org_secret 

pub async fn actions_slash_get_org_secret(
    configuration: &Configuration,
    org: &str,
    secret_name: &str,
) -> Result<OrganizationActionsSecret, Error<ActionsSlashGetOrgSecretError>>
Gets a single organization secret without revealing its encrypted value. The authenticated user must have collaborator access to a repository to create, update, or read secrets OAuth tokens and personal access tokens (classic) need theadmin:org scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the repo scope to use this endpoint.