checks_slash_create

Function checks_slash_create 

pub async fn checks_slash_create(
    configuration: &Configuration,
    owner: &str,
    repo: &str,
    checks_create_request: ChecksCreateRequest,
) -> Result<CheckRun, Error<ChecksSlashCreateError>>
Note: The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty pull_requests array. Creates a new check run for a specific commit in a repository. Your GitHub App must have the checks:write permission to create check runs. In a check suite, GitHub limits the number of check runs with the same name to 1000. Once these check runs exceed 1000, GitHub will start to automatically delete older check runs.