checks_slash_create_suite

Function checks_slash_create_suite 

pub async fn checks_slash_create_suite(
    configuration: &Configuration,
    owner: &str,
    repo: &str,
    checks_create_suite_request: ChecksCreateSuiteRequest,
) -> Result<CheckSuite, Error<ChecksSlashCreateSuiteError>>
Creates a check suite manually. By default, check suites are automatically created when you create a check run. You only need to use this endpoint for manually creating check suites when you’ve disabled automatic creation using "Update repository preferences for check suites". Note: The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty pull_requests array and a null value for head_branch. OAuth apps and personal access tokens (classic) cannot use this endpoint.