checks_slash_list_annotations

Function checks_slash_list_annotations 

pub async fn checks_slash_list_annotations(
    configuration: &Configuration,
    owner: &str,
    repo: &str,
    check_run_id: i32,
    per_page: Option<i32>,
    page: Option<i32>,
) -> Result<Vec<CheckAnnotation>, Error<ChecksSlashListAnnotationsError>>
Lists annotations for a check run using the annotation id. OAuth app tokens and personal access tokens (classic) need the repo scope to use this endpoint on a private repository.