checks_slash_rerequest_run

Function checks_slash_rerequest_run 

pub async fn checks_slash_rerequest_run(
    configuration: &Configuration,
    owner: &str,
    repo: &str,
    check_run_id: i32,
) -> Result<Value, Error<ChecksSlashRerequestRunError>>
Triggers GitHub to rerequest an existing check run, without pushing new code to a repository. This endpoint will trigger the check_run webhook event with the action rerequested. When a check run is rerequested, its status is reset to queued and the conclusion is cleared. For more information about how to re-run GitHub Actions jobs, see "Re-run a job from a workflow run". OAuth apps and personal access tokens (classic) cannot use this endpoint.