copilot_slash_list_copilot_seats

Function copilot_slash_list_copilot_seats 

pub async fn copilot_slash_list_copilot_seats(
    configuration: &Configuration,
    org: &str,
    page: Option<i32>,
    per_page: Option<i32>,
) -> Result<CopilotListCopilotSeats200Response, Error<CopilotSlashListCopilotSeatsError>>
Note: This endpoint is in beta and is subject to change. Lists all Copilot seat assignments for an organization that are currently being billed (either active or pending cancellation at the start of the next billing cycle). Only organization owners can configure and view details about the organization’s Copilot Business or Enterprise subscription. OAuth app tokens and personal access tokens (classic) need the manage_billing:copilot scope to use this endpoint.