pub async fn dependabot_slash_update_alert(
configuration: &Configuration,
owner: &str,
repo: &str,
alert_number: i32,
dependabot_update_alert_request: DependabotUpdateAlertRequest,
) -> Result<DependabotAlert, Error<DependabotSlashUpdateAlertError>>Expand description
The authenticated user must have access to security alerts for the repository to use this endpoint. For more information, see "Granting access to security alerts." OAuth app tokens and personal access tokens (classic) need the security_events scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the public_repo scope instead.