pub async fn emojis_slash_get(
configuration: &Configuration,
) -> Result<HashMap<String, String>, Error<EmojisSlashGetError>>Expand description
Lists all the emojis available to use on GitHub.
pub async fn emojis_slash_get(
configuration: &Configuration,
) -> Result<HashMap<String, String>, Error<EmojisSlashGetError>>Lists all the emojis available to use on GitHub.