orgs_slash_get_webhook_delivery

Function orgs_slash_get_webhook_delivery 

pub async fn orgs_slash_get_webhook_delivery(
    configuration: &Configuration,
    org: &str,
    hook_id: i32,
    delivery_id: i32,
) -> Result<HookDelivery, Error<OrgsSlashGetWebhookDeliveryError>>
Returns a delivery for a webhook configured in an organization. You must be an organization owner to use this endpoint. OAuth app tokens and personal access tokens (classic) need admin:org_hook scope. OAuth apps cannot list, view, or edit webhooks that they did not create and users cannot list, view, or edit webhooks that were created by OAuth apps.