orgs_slash_remove_custom_property

Function orgs_slash_remove_custom_property 

pub async fn orgs_slash_remove_custom_property(
    configuration: &Configuration,
    org: &str,
    custom_property_name: &str,
) -> Result<(), Error<OrgsSlashRemoveCustomPropertyError>>
Removes a custom property that is defined for an organization. To use this endpoint, the authenticated user must be one of: - An administrator for the organization. - A user, or a user on a team, with the fine-grained permission of custom_properties_org_definitions_manager in the organization.