orgs_slash_remove_member

Function orgs_slash_remove_member 

pub async fn orgs_slash_remove_member(
    configuration: &Configuration,
    org: &str,
    username: &str,
) -> Result<(), Error<OrgsSlashRemoveMemberError>>
Removing a user from this list will remove them from all teams and they will no longer have any access to the organization’s repositories.