pub struct ChecksCreateRequest {
pub name: String,
pub head_sha: String,
pub details_url: Option<String>,
pub external_id: Option<String>,
pub status: Option<Status>,
pub started_at: Option<String>,
pub conclusion: Option<Conclusion>,
pub completed_at: Option<String>,
pub output: Option<Box<ChecksCreateRequestOutput>>,
pub actions: Option<Vec<ChecksCreateRequestActionsInner>>,
}Fields
name: StringThe name of the check. For example, "code-coverage".
head_sha: StringThe SHA of the commit.
details_url: Option<String>The URL of the integrator’s site that has the full details of the check. If the integrator does not provide this, then the homepage of the GitHub app is used.
external_id: Option<String>A reference for the run on the integrator’s system.
status: Option<Status>The current status.
started_at: Option<String>The time that the check run began. This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
conclusion: Option<Conclusion>Required if you provide completed_at or a status of completed. The final conclusion of the check. Note: Providing conclusion will automatically set the status parameter to completed. You cannot change a check run conclusion to stale, only GitHub can set this.
completed_at: Option<String>The time the check completed. This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
output: Option<Box<ChecksCreateRequestOutput>>actions: Option<Vec<ChecksCreateRequestActionsInner>>Displays a button on GitHub that can be clicked to alert your app to do additional tasks. For example, a code linting app can display a button that automatically fixes detected errors. The button created in this object is displayed after the check run completes. When a user clicks the button, GitHub sends the check_run.requested_action webhook to your app. Each action includes a label, identifier and description. A maximum of three actions are accepted. To learn more about check runs and requested actions, see "Check runs and requested actions."
Implementations
Sourceimpl ChecksCreateRequest
impl ChecksCreateRequest
pub fn new(name: String, head_sha: String) -> ChecksCreateRequest