Module checks_update_request

Module checks_update_request 

Structs

ChecksUpdateRequest

Enums

Conclusion
Required if you provide completed_at or a status of completed. The final conclusion of the check. Note: Providing conclusion will automatically set the status parameter to completed. You cannot change a check run conclusion to stale, only GitHub can set this.
Status
The current status of the check run. Only GitHub Actions can set a status of waiting, pending, or requested.