pub struct DependabotAlert {Show 15 fields
pub number: i32,
pub state: State,
pub dependency: Box<DependabotAlertWithRepositoryDependency>,
pub security_advisory: Box<DependabotAlertSecurityAdvisory>,
pub security_vulnerability: Box<DependabotAlertSecurityVulnerability>,
pub url: String,
pub html_url: String,
pub created_at: String,
pub updated_at: String,
pub dismissed_at: Option<String>,
pub dismissed_by: Option<Box<NullableSimpleUser>>,
pub dismissed_reason: Option<DismissedReason>,
pub dismissed_comment: Option<String>,
pub fixed_at: Option<String>,
pub auto_dismissed_at: Option<Option<String>>,
}Expand description
DependabotAlert : A Dependabot alert.
Fields
number: i32The security alert number.
state: StateThe state of the Dependabot alert.
dependency: Box<DependabotAlertWithRepositoryDependency>security_advisory: Box<DependabotAlertSecurityAdvisory>security_vulnerability: Box<DependabotAlertSecurityVulnerability>url: StringThe REST API URL of the alert resource.
html_url: StringThe GitHub URL of the alert resource.
created_at: StringThe time that the alert was created in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
updated_at: StringThe time that the alert was last updated in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
dismissed_at: Option<String>The time that the alert was dismissed in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
dismissed_by: Option<Box<NullableSimpleUser>>dismissed_reason: Option<DismissedReason>The reason that the alert was dismissed.
dismissed_comment: Option<String>An optional comment associated with the alert’s dismissal.
fixed_at: Option<String>The time that the alert was no longer detected and was considered fixed in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
auto_dismissed_at: Option<Option<String>>The time that the alert was auto-dismissed in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
Implementations
Sourceimpl DependabotAlert
impl DependabotAlert
Sourcepub fn new(
number: i32,
state: State,
dependency: DependabotAlertWithRepositoryDependency,
security_advisory: DependabotAlertSecurityAdvisory,
security_vulnerability: DependabotAlertSecurityVulnerability,
url: String,
html_url: String,
created_at: String,
updated_at: String,
dismissed_at: Option<String>,
dismissed_by: Option<NullableSimpleUser>,
dismissed_reason: Option<DismissedReason>,
dismissed_comment: Option<String>,
fixed_at: Option<String>,
) -> DependabotAlert
pub fn new( number: i32, state: State, dependency: DependabotAlertWithRepositoryDependency, security_advisory: DependabotAlertSecurityAdvisory, security_vulnerability: DependabotAlertSecurityVulnerability, url: String, html_url: String, created_at: String, updated_at: String, dismissed_at: Option<String>, dismissed_by: Option<NullableSimpleUser>, dismissed_reason: Option<DismissedReason>, dismissed_comment: Option<String>, fixed_at: Option<String>, ) -> DependabotAlert
A Dependabot alert.