pub struct DependabotAlertSecurityAdvisory {Show 13 fields
pub ghsa_id: String,
pub cve_id: Option<String>,
pub summary: String,
pub description: String,
pub vulnerabilities: Vec<DependabotAlertSecurityVulnerability>,
pub severity: Severity,
pub cvss: Box<DependabotAlertSecurityAdvisoryCvss>,
pub cwes: Vec<DependabotAlertSecurityAdvisoryCwesInner>,
pub identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiersInner>,
pub references: Vec<DependabotAlertSecurityAdvisoryReferencesInner>,
pub published_at: String,
pub updated_at: String,
pub withdrawn_at: Option<String>,
}Expand description
DependabotAlertSecurityAdvisory : Details for the GitHub Security Advisory.
Fields
ghsa_id: StringThe unique GitHub Security Advisory ID assigned to the advisory.
cve_id: Option<String>The unique CVE ID assigned to the advisory.
summary: StringA short, plain text summary of the advisory.
description: StringA long-form Markdown-supported description of the advisory.
vulnerabilities: Vec<DependabotAlertSecurityVulnerability>Vulnerable version range information for the advisory.
severity: SeverityThe severity of the advisory.
cvss: Box<DependabotAlertSecurityAdvisoryCvss>cwes: Vec<DependabotAlertSecurityAdvisoryCwesInner>Details for the advisory pertaining to Common Weakness Enumeration.
identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiersInner>Values that identify this advisory among security information sources.
references: Vec<DependabotAlertSecurityAdvisoryReferencesInner>Links to additional advisory information.
published_at: StringThe time that the advisory was published in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
updated_at: StringThe time that the advisory was last modified in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
withdrawn_at: Option<String>The time that the advisory was withdrawn in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
Implementations
Sourceimpl DependabotAlertSecurityAdvisory
impl DependabotAlertSecurityAdvisory
Sourcepub fn new(
ghsa_id: String,
cve_id: Option<String>,
summary: String,
description: String,
vulnerabilities: Vec<DependabotAlertSecurityVulnerability>,
severity: Severity,
cvss: DependabotAlertSecurityAdvisoryCvss,
cwes: Vec<DependabotAlertSecurityAdvisoryCwesInner>,
identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiersInner>,
references: Vec<DependabotAlertSecurityAdvisoryReferencesInner>,
published_at: String,
updated_at: String,
withdrawn_at: Option<String>,
) -> DependabotAlertSecurityAdvisory
pub fn new( ghsa_id: String, cve_id: Option<String>, summary: String, description: String, vulnerabilities: Vec<DependabotAlertSecurityVulnerability>, severity: Severity, cvss: DependabotAlertSecurityAdvisoryCvss, cwes: Vec<DependabotAlertSecurityAdvisoryCwesInner>, identifiers: Vec<DependabotAlertSecurityAdvisoryIdentifiersInner>, references: Vec<DependabotAlertSecurityAdvisoryReferencesInner>, published_at: String, updated_at: String, withdrawn_at: Option<String>, ) -> DependabotAlertSecurityAdvisory
Details for the GitHub Security Advisory.