pub struct DependabotAlertSecurityVulnerability {
pub package: Box<DependabotAlertPackage>,
pub severity: Severity,
pub vulnerable_version_range: String,
pub first_patched_version: Option<Box<DependabotAlertSecurityVulnerabilityFirstPatchedVersion>>,
}Expand description
DependabotAlertSecurityVulnerability : Details pertaining to one vulnerable version range for the advisory.
Fields
package: Box<DependabotAlertPackage>severity: SeverityThe severity of the vulnerability.
vulnerable_version_range: StringConditions that identify vulnerable versions of this vulnerability’s package.
first_patched_version: Option<Box<DependabotAlertSecurityVulnerabilityFirstPatchedVersion>>Implementations
Sourceimpl DependabotAlertSecurityVulnerability
impl DependabotAlertSecurityVulnerability
Sourcepub fn new(
package: DependabotAlertPackage,
severity: Severity,
vulnerable_version_range: String,
first_patched_version: Option<DependabotAlertSecurityVulnerabilityFirstPatchedVersion>,
) -> DependabotAlertSecurityVulnerability
pub fn new( package: DependabotAlertPackage, severity: Severity, vulnerable_version_range: String, first_patched_version: Option<DependabotAlertSecurityVulnerabilityFirstPatchedVersion>, ) -> DependabotAlertSecurityVulnerability
Details pertaining to one vulnerable version range for the advisory.