pub struct DependabotAlertSecurityVulnerabilityFirstPatchedVersion {
pub identifier: String,
}Expand description
DependabotAlertSecurityVulnerabilityFirstPatchedVersion : Details pertaining to the package version that patches this vulnerability.
Fields
identifier: StringThe package version that patches this vulnerability.
Implementations
Sourceimpl DependabotAlertSecurityVulnerabilityFirstPatchedVersion
impl DependabotAlertSecurityVulnerabilityFirstPatchedVersion
Sourcepub fn new(
identifier: String,
) -> DependabotAlertSecurityVulnerabilityFirstPatchedVersion
pub fn new( identifier: String, ) -> DependabotAlertSecurityVulnerabilityFirstPatchedVersion
Details pertaining to the package version that patches this vulnerability.