pub struct DependabotCreateOrUpdateRepoSecretRequest {
pub encrypted_value: Option<String>,
pub key_id: Option<String>,
}Fields
encrypted_value: Option<String>Value for your secret, encrypted with LibSodium using the public key retrieved from the Get a repository public key endpoint.
key_id: Option<String>ID of the key you used to encrypt the secret.
Implementations