Module enabled_repositories

Module enabled_repositories 

Enums

EnabledRepositories
EnabledRepositories : The policy that controls the repositories in the organization that are allowed to run GitHub Actions. The policy that controls the repositories in the organization that are allowed to run GitHub Actions.