pub struct GitCreateCommitRequest {
pub message: String,
pub tree: String,
pub parents: Option<Vec<String>>,
pub author: Option<Box<GitCreateCommitRequestAuthor>>,
pub committer: Option<Box<GitCreateCommitRequestCommitter>>,
pub signature: Option<String>,
}Fields
message: StringThe commit message
tree: StringThe SHA of the tree object this commit points to
parents: Option<Vec<String>>The SHAs of the commits that were the parents of this commit. If omitted or empty, the commit will be written as a root commit. For a single parent, an array of one SHA should be provided; for a merge commit, an array of more than one should be provided.
committer: Option<Box<GitCreateCommitRequestCommitter>>signature: Option<String>The PGP signature of the commit. GitHub adds the signature to the gpgsig header of the created commit. For a commit signature to be verifiable by Git or GitHub, it must be an ASCII-armored detached PGP signature over the string commit as it would be written to the object database. To pass a signature parameter, you need to first manually create a valid PGP signature, which can be complicated. You may find it easier to use the command line to create signed commits.
Implementations
Sourceimpl GitCreateCommitRequest
impl GitCreateCommitRequest
pub fn new(message: String, tree: String) -> GitCreateCommitRequest