UseLfs

pub enum UseLfs {
    In,
    Out,
}
Whether to store large files during the import. opt_in means large files will be stored using Git LFS. opt_out means large files will be removed during the import.

Variants



In



Out