pub struct NullableCodespaceMachine {
pub name: String,
pub display_name: String,
pub operating_system: String,
pub storage_in_bytes: i32,
pub memory_in_bytes: i32,
pub cpus: i32,
pub prebuild_availability: Option<PrebuildAvailability>,
}Expand description
NullableCodespaceMachine : A description of the machine powering a codespace.
Fields
name: StringThe name of the machine.
display_name: StringThe display name of the machine includes cores, memory, and storage.
operating_system: StringThe operating system of the machine.
storage_in_bytes: i32How much storage is available to the codespace.
memory_in_bytes: i32How much memory is available to the codespace.
cpus: i32How many cores are available to the codespace.
prebuild_availability: Option<PrebuildAvailability>Whether a prebuild is currently available when creating a codespace for this machine and repository. If a branch was not specified as a ref, the default branch will be assumed. Value will be "null" if prebuilds are not supported or prebuild availability could not be determined. Value will be "none" if no prebuild is available. Latest values "ready" and "in_progress" indicate the prebuild availability status.
Implementations