pub struct OrgsCreateInvitationRequest {
pub invitee_id: Option<i32>,
pub email: Option<String>,
pub role: Option<Role>,
pub team_ids: Option<Vec<i32>>,
}Fields
invitee_id: Option<i32>Required unless you provide email. GitHub user ID for the person you are inviting.
email: Option<String>Required unless you provide invitee_id. Email address of the person you are inviting, which can be an existing GitHub user.
role: Option<Role>The role for the new member. * admin - Organization owners with full administrative rights to the organization and complete access to all repositories and teams. * direct_member - Non-owner organization members with ability to see other members and join teams by invitation. * billing_manager - Non-owner organization members with ability to manage the billing settings of your organization. * reinstate - The previous role assigned to the invitee before they were removed from your organization. Can be one of the roles listed above. Only works if the invitee was previously part of your organization.
team_ids: Option<Vec<i32>>Specify IDs for the teams you want to invite new members to.
Implementations
Sourceimpl OrgsCreateInvitationRequest
impl OrgsCreateInvitationRequest
pub fn new() -> OrgsCreateInvitationRequest