Structs
Enums
- Build
Type - The process by which the GitHub Pages site will be built.
workflowmeans that the site is built by a custom GitHub Actions workflow.legacymeans that the site is built by GitHub when changes are pushed to a specific branch.