pub struct RepositoryRuleDetailedOneOf13 {
pub type: Type,
pub parameters: Option<Box<RepositoryRuleCommitMessagePatternParameters>>,
pub ruleset_source_type: Option<RulesetSourceType>,
pub ruleset_source: Option<String>,
pub ruleset_id: Option<i32>,
}Fields
type: Typeparameters: Option<Box<RepositoryRuleCommitMessagePatternParameters>>ruleset_source_type: Option<RulesetSourceType>The type of source for the ruleset that includes this rule.
ruleset_source: Option<String>The name of the source of the ruleset that includes this rule.
ruleset_id: Option<i32>The ID of the ruleset that includes this rule.
Implementations
Sourceimpl RepositoryRuleDetailedOneOf13
impl RepositoryRuleDetailedOneOf13
pub fn new(type: Type) -> RepositoryRuleDetailedOneOf13