pub struct RepositoryRuleDetailedOneOf7 {
pub type: Type,
pub parameters: Option<Box<RepositoryRuleRequiredStatusChecksParameters>>,
pub ruleset_source_type: Option<RulesetSourceType>,
pub ruleset_source: Option<String>,
pub ruleset_id: Option<i32>,
}Fields
type: Typeparameters: Option<Box<RepositoryRuleRequiredStatusChecksParameters>>ruleset_source_type: Option<RulesetSourceType>The type of source for the ruleset that includes this rule.
ruleset_source: Option<String>The name of the source of the ruleset that includes this rule.
ruleset_id: Option<i32>The ID of the ruleset that includes this rule.
Implementations
Sourceimpl RepositoryRuleDetailedOneOf7
impl RepositoryRuleDetailedOneOf7
pub fn new(type: Type) -> RepositoryRuleDetailedOneOf7