pub struct ReviewCustomGatesStateRequired {
pub environment_name: String,
pub state: State,
pub comment: Option<String>,
}Fields
environment_name: StringThe name of the environment to approve or reject.
state: StateWhether to approve or reject deployment to the specified environments.
comment: Option<String>Optional comment to include with the review.
Implementations
Sourceimpl ReviewCustomGatesStateRequired
impl ReviewCustomGatesStateRequired
pub fn new( environment_name: String, state: State, ) -> ReviewCustomGatesStateRequired