Module secret_scanning_alert_state

Module secret_scanning_alert_state 

Enums

SecretScanningAlertState
SecretScanningAlertState : Sets the state of the secret scanning alert. You must provide resolution when you set the state to resolved. Sets the state of the secret scanning alert. You must provide resolution when you set the state to resolved.