pub struct SecretScanningLocation {
pub type: Option<Type>,
pub details: Option<Box<SecretScanningLocationDetails>>,
}Fields
type: Option<Type>The location type. Because secrets may be found in different types of resources (ie. code, comments, issues, pull requests, discussions), this field identifies the type of resource where the secret was found.
details: Option<Box<SecretScanningLocationDetails>>Implementations
Sourceimpl SecretScanningLocation
impl SecretScanningLocation
pub fn new() -> SecretScanningLocation