pub struct SecretScanningLocationDiscussionBody {
pub discussion_body_url: String,
}Expand description
SecretScanningLocationDiscussionBody : Represents a ‘discussion_body’ secret scanning location type. This location type shows that a secret was detected in the body of a discussion.
Fields
discussion_body_url: StringThe URL to the discussion where the secret was detected.
Implementations
Sourceimpl SecretScanningLocationDiscussionBody
impl SecretScanningLocationDiscussionBody
Sourcepub fn new(discussion_body_url: String) -> SecretScanningLocationDiscussionBody
pub fn new(discussion_body_url: String) -> SecretScanningLocationDiscussionBody
Represents a ‘discussion_body’ secret scanning location type. This location type shows that a secret was detected in the body of a discussion.