pub struct SecretScanningLocationDiscussionTitle {
pub discussion_title_url: String,
}Expand description
SecretScanningLocationDiscussionTitle : Represents a ‘discussion_title’ secret scanning location type. This location type shows that a secret was detected in the title of a discussion.
Fields
discussion_title_url: StringThe URL to the discussion where the secret was detected.
Implementations
Sourceimpl SecretScanningLocationDiscussionTitle
impl SecretScanningLocationDiscussionTitle
Sourcepub fn new(
discussion_title_url: String,
) -> SecretScanningLocationDiscussionTitle
pub fn new( discussion_title_url: String, ) -> SecretScanningLocationDiscussionTitle
Represents a ‘discussion_title’ secret scanning location type. This location type shows that a secret was detected in the title of a discussion.