pub struct SecretScanningLocationIssueBody {
pub issue_body_url: String,
}Expand description
SecretScanningLocationIssueBody : Represents an ‘issue_body’ secret scanning location type. This location type shows that a secret was detected in the body of an issue.
Fields
issue_body_url: StringThe API URL to get the issue where the secret was detected.
Implementations
Sourceimpl SecretScanningLocationIssueBody
impl SecretScanningLocationIssueBody
Sourcepub fn new(issue_body_url: String) -> SecretScanningLocationIssueBody
pub fn new(issue_body_url: String) -> SecretScanningLocationIssueBody
Represents an ‘issue_body’ secret scanning location type. This location type shows that a secret was detected in the body of an issue.