pub struct SecretScanningLocationIssueTitle {
pub issue_title_url: String,
}Expand description
SecretScanningLocationIssueTitle : Represents an ‘issue_title’ secret scanning location type. This location type shows that a secret was detected in the title of an issue.
Fields
issue_title_url: StringThe API URL to get the issue where the secret was detected.
Implementations
Sourceimpl SecretScanningLocationIssueTitle
impl SecretScanningLocationIssueTitle
Sourcepub fn new(issue_title_url: String) -> SecretScanningLocationIssueTitle
pub fn new(issue_title_url: String) -> SecretScanningLocationIssueTitle
Represents an ‘issue_title’ secret scanning location type. This location type shows that a secret was detected in the title of an issue.