Structs
- Sponsorship
Tier - SponsorshipTier : The
tier_changedandpending_tier_changewill include the original tier before the change or pending change. For more information, see the pending tier change payload.
tier_changed and pending_tier_change will include the original tier before the change or pending change. For more information, see the pending tier change payload.