pub struct TeamsCreateRequest {
pub name: String,
pub description: Option<String>,
pub maintainers: Option<Vec<String>>,
pub repo_names: Option<Vec<String>>,
pub privacy: Option<Privacy>,
pub notification_setting: Option<NotificationSetting>,
pub permission: Option<Permission>,
pub parent_team_id: Option<i32>,
}Fields
name: StringThe name of the team.
description: Option<String>The description of the team.
maintainers: Option<Vec<String>>List GitHub IDs for organization members who will become team maintainers.
repo_names: Option<Vec<String>>The full name (e.g., "organization-name/repository-name") of repositories to add the team to.
privacy: Option<Privacy>The level of privacy this team should have. The options are: For a non-nested team: * secret - only visible to organization owners and members of this team. * closed - visible to all members of this organization. Default: secret For a parent or child team: * closed - visible to all members of this organization. Default for child team: closed
notification_setting: Option<NotificationSetting>The notification setting the team has chosen. The options are: * notifications_enabled - team members receive notifications when the team is @mentioned. * notifications_disabled - no one receives notifications. Default: notifications_enabled
permission: Option<Permission>Deprecated. The permission that new repositories will be added to the team with when none is specified.
parent_team_id: Option<i32>The ID of a team to set as the parent team.
Implementations
Sourceimpl TeamsCreateRequest
impl TeamsCreateRequest
pub fn new(name: String) -> TeamsCreateRequest