pub enum WebhooksRepositorySelection {
All,
Selected,
}Expand description
WebhooksRepositorySelection : Describe whether all repositories have been selected or there’s a selection involved Describe whether all repositories have been selected or there’s a selection involved
Variants