pub async fn actions_slash_delete_org_secret(
configuration: &Configuration,
org: &str,
secret_name: &str,
) -> Result<(), Error<ActionsSlashDeleteOrgSecretError>>Expand description
Deletes a secret in an organization using the secret name. Authenticated users must have collaborator access to a repository to create, update, or read secrets. OAuth tokens and personal access tokens (classic) need theadmin:org scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the repo scope to use this endpoint.