pub async fn orgs_slash_remove_member(
configuration: &Configuration,
org: &str,
username: &str,
) -> Result<(), Error<OrgsSlashRemoveMemberError>>Expand description
Removing a user from this list will remove them from all teams and they will no longer have any access to the organization’s repositories.